import time
import click
from watchdog.observers import Observer
from watchdog.events import FileSystemEventHandler
import subprocess


class JMCWatchdog(FileSystemEventHandler):

	def __init__(self):
		self.compilation_needed = False

	def on_any_event(self, event):
		if not self.compilation_needed and '.jmc' in event.src_path:
			compile_result = subprocess.run('jmc compile',
											capture_output=True,
											text=True,
											shell=True)
			print(compile_result.stdout)
			self.compilation_needed = True


@click.command()
def main():
	"""Look for changes in .jmc files and compile them.\n
	To use simply type `jmcwatch` in the directory of your JMC project\n
	JMCWatch is made by amandin. (discord handle)"""
	event_handler = JMCWatchdog()
	observer = Observer()
	observer.schedule(event_handler, ".", recursive=True)
	observer.start()
	try:
		while True:
			time.sleep(1)
			event_handler.compilation_needed = False
	except KeyboardInterrupt:
		observer.stop()
	observer.join()


if __name__ == "__main__":
	main()



# jmcwatch/__init__.py

# Define a package-level variable
# PACKAGE_VERSION = '0.1.4'

# Import the main function from your CLI module
from .cli import main

# Initialize package-level configuration
CONFIG = {
    'debug': False,
}

# Optionally, define what should be available when someone uses "from package import *"
__all__ = ['main', 'PACKAGE_VERSION']



from setuptools import setup, find_packages

setup(
    name='jmcwatch',
    version='0.1.4',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'jmcwatch=jmcwatch.cli:main',
        ],
    },
    install_requires=[
        'click',
        'watchdog',
    ],
    author='amandin',
    author_email='amawwdin@email.com',
    description='Watch and compile JMC files. Simply type `jmcwatch` to use.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    license='MIT',
)
